@@ -4,6 +4,7 @@
 #include <cstdint>
 #include <fstream>
 #include <string>
+#include <vector>
 
 #include "gzstream/gzstream.h"
 
@@ -17,9 +18,10 @@ struct GTFLine {
     int end;
     std::string strand;
     std::string symbol;
+    std::vector<std::string> alternate_ids;
     std::string tx_id;
     std::string transcript_type;
-    int is_canonical;
+    int is_canonical = 0;
 };
 
 GTFLine parse_gtfline(std::string &line);
@@ -39,4 +41,4 @@ public:
 
 } // namespace
 
-#endif // GENCODEGENES_GTF_H_
\ No newline at end of file
+#endif // GENCODEGENES_GTF_H_
