@@ -10,7 +10,9 @@
 
 #include "tx.h"
 
-std::unordered_map<std::string, char> aa_code = {
+namespace gencode {
+
+static std::unordered_map<std::string, char> aa_code = {
     {"AAA", 'K'}, {"AAC", 'N'}, {"AAG", 'K'}, {"AAT", 'N'},
     {"ACA", 'T'}, {"ACC", 'T'}, {"ACG", 'T'}, {"ACT", 'T'},
     {"AGA", 'R'}, {"AGC", 'S'}, {"AGG", 'R'}, {"AGT", 'S'},
@@ -48,8 +50,7 @@ Tx::Tx(std::string transcript_id, std::string chromosome,
 // set exon ranges to the class object
 //
 // @param exon_ranges list of lists e.g. [[5, 10], [20, 30]]
-void Tx::set_exons(std::vector<std::vector<int>> exon_ranges,
-    std::vector<std::vector<int>> cds_ranges) {
+void Tx::set_exons(std::vector<std::vector<int>> exon_ranges) {
     exons.clear();
     std::sort(exon_ranges.begin(), exon_ranges.end());
     
@@ -57,22 +58,6 @@ void Tx::set_exons(std::vector<std::vector<int>> exon_ranges,
         Region region {range[0], range[1]};
         exons.push_back(region);
     }
-    
-    // If the transcript lacks exon coordinates and only has a single CDS
-    // region, then if the CDS region fits within the gene range, make a
-    // single exon, using the transcript start and end. This prevents issues
-    // when adding the CDS coordinates for the transcript.
-    if (exons.empty()) {
-        std::vector<int> exon = cds_ranges[0];
-        if (cds_ranges.size() == 1 && std::min(exon[0], exon[1]) >= tx_start \
-                && std::max(exon[0], exon[1]) <= tx_end) {
-            Region region {tx_start, tx_end};
-            exons.push_back(region);
-        } else {
-            std::string msg = get_name() + " lacks exon coordinates";
-            throw std::invalid_argument( msg );
-        }
-    }
 }
 
 // set CDS ranges to the class object
@@ -81,8 +66,24 @@ void Tx::set_exons(std::vector<std::vector<int>> exon_ranges,
 void Tx::set_cds(std::vector<std::vector<int>> cds_ranges) {
    cds.clear();
    
+   if (cds_ranges.size() == 0) {
+    return;
+   }
+   
+   // If the transcript lacks exon coordinates and only has a single CDS
+    // region, then if the CDS region fits within the gene range, make a
+    // single exon, using the transcript start and end. This prevents issues
+    // when adding the CDS coordinates for the transcript.
     if ( exons.empty() ) {
-        throw std::invalid_argument( "you need to set the exons before the CDS" );
+        std::vector<int> exon = cds_ranges[0];
+        if (cds_ranges.size() == 1 && std::min(exon[0], exon[1]) >= tx_start \
+                && std::max(exon[0], exon[1]) <= tx_end) {
+            Region region {tx_start, tx_end};
+            exons.push_back(region);
+        } else {
+            std::string msg = get_name() + " lacks exon coordinates";
+            throw std::invalid_argument( msg );
+        }
     }
     
     std::sort(cds_ranges.begin(), cds_ranges.end());
@@ -202,7 +203,7 @@ bool Tx::is_exonic(int pos, Region exon) {
 
 // include a sort operator for Region structs. This allows quick searching
 // of vectors of Regions
-bool compareRegion(const Region& a, int b) {
+static bool compareRegion(const Region& a, int b) {
     return a.start < b;
 }
 
@@ -215,12 +216,12 @@ int Tx::closest_exon_num(int pos) {
 //
 // @param position chromosomal nucleotide position
 // @returns number of exon containing the position
-int Tx::closest_exon_num(int pos, std::vector<Region> group) {
+int Tx::closest_exon_num(int pos, std::vector<Region> & group) {
     size_t idx = std::lower_bound(group.begin(), group.end(), pos, compareRegion) - group.begin();
     size_t size = group.size();
     if (idx == 0) {
         return idx;
-    } else if ((idx == size) && (pos > group[idx - 1].end)) {
+    } else if ((idx == size) && (pos > group[idx - 1].start)) {
         return idx - 1;
     }
     
@@ -250,6 +251,9 @@ int Tx::closest_exon_num(int pos, std::vector<Region> group) {
 //
 // @param position integer chromosome position e.g. 10000000
 Region Tx::get_closest_exon(int pos) {
+    if (exons.size() == 0) {
+        throw std::invalid_argument("no exons assigned to this transcript");
+    }
     int idx = closest_exon_num(pos);
     return exons[idx];
 }
@@ -258,6 +262,9 @@ Region Tx::get_closest_exon(int pos) {
 //
 // @param position integer chromosome position e.g. 10000000
 bool Tx::in_coding_region(int pos) {
+    if (cds.size() == 0) {
+        return false;
+    }
     int idx = closest_exon_num(pos, cds);
     Region region = cds[idx];
     return (pos >= region.start) && (pos <= region.end);
@@ -404,19 +411,18 @@ void Tx::add_cds_sequence(std::string cds_dna) {
 // @param gdna string for genomic sequence. If the transcript strand is '-',
 //    then the DNA sequence will be for the - strand, so we need to
 //    reorient the DNA to the + strand.
-void Tx::add_genomic_sequence(std::string gdna, int offset=0) {
+void Tx::add_genomic_sequence(std::string gdna) {
     char fwd = '+';
     if (get_strand() != fwd) {
         // orient the DNA sequence to the + strand.
         gdna = reverse_complement(gdna);
     }
     
-    gdna_offset = offset;
     genomic_sequence = gdna;
     
     std::string cds_seq;
     for (auto &region : cds) {
-        int x = std::abs(region.start - get_start()) + offset;
+        int x = std::abs(region.start - get_start()) + gdna_offset;
         int len = (region.end - region.start) + 1;
         std::string bases = genomic_sequence.substr(x, len);
         
@@ -498,10 +504,17 @@ void Tx::_fix_cds_length() {
 // reverse complement a DNA or RNA sequence
 std::string Tx::reverse_complement(std::string seq) {
     static char transdict[128];
-    transdict['a'] = 't'; transdict['c'] = 'g'; transdict['g'] = 'c'; 
-    transdict['t'] = 'a'; transdict['u'] = 'a'; transdict['A'] = 'T'; 
-    transdict['C'] = 'G'; transdict['G'] = 'C'; transdict['T'] = 'A'; 
-    transdict['U'] = 'A'; transdict['N'] = 'N';
+    transdict[(int) 'a'] = 't';
+    transdict[(int) 'c'] = 'g';
+    transdict[(int) 'g'] = 'c';
+    transdict[(int) 't'] = 'a';
+    transdict[(int) 'u'] = 'a';
+    transdict[(int) 'A'] = 'T';
+    transdict[(int) 'C'] = 'G';
+    transdict[(int) 'G'] = 'C';
+    transdict[(int) 'T'] = 'A';
+    transdict[(int) 'U'] = 'A';
+    transdict[(int) 'N'] = 'N';
     std::reverse(seq.begin(), seq.end());
     std::string complement;
     complement.resize(seq.size());
@@ -640,7 +653,7 @@ int Tx::get_boundary_distance(int bp) {
 }
 
 // check for overlap of two ranges
-bool overlap(const int & start1, const int & end1, const int & start2, const int & end2) {
+static bool overlap(const int & start1, const int & end1, const int & start2, const int & end2) {
     return (end1 >= start2) && (end2 >= start1);
 }
 
@@ -661,7 +674,7 @@ bool Tx::overlaps_cds(int start, int end) {
     return false;
 }
 
-std::string Tx::outside_gene_cq(int start, int end, std::string alt) {
+std::string Tx::outside_gene_cq(int start, int end) {
     bool fwd = get_strand() == '+';
     if ((end < tx_start) & ((tx_start - end) <= 5000)) {
         if (fwd) {
@@ -781,7 +794,7 @@ std::string Tx::indel_cq(int start, int end, std::string ref, std::string alt) {
     }
 }
 
-std::string Tx::coding_cq(int start, int end, std::string alt) {
+std::string Tx::coding_cq(int start, std::string alt) {
     if (get_strand() == '-') {
         alt = reverse_complement(alt);
     }
@@ -841,7 +854,7 @@ std::string Tx::consequence(int pos, std::string ref, std::string alt) {
     trim_alleles(start, end, ref, alt);
     
     if ((end < tx_start) | (start > tx_end)) {
-        return outside_gene_cq(start, end, alt);
+        return outside_gene_cq(start, end);
     }
     
     if (!overlaps_cds(start, end)) {
@@ -854,5 +867,7 @@ std::string Tx::consequence(int pos, std::string ref, std::string alt) {
         return indel_cq(start, end, ref, alt);
     }
     
-    return coding_cq(start, end, alt);
+    return coding_cq(start, alt);
 }
+
+} // namespace
\ No newline at end of file
