@@ -55,12 +55,12 @@ class TestGencode(unittest.TestCase):
         lines = '##format: gtf\n' \
                 'chr1\tHAVANA\tgene\t10\t20\t.\t-\t.\tgene_name "TEST1";\n' \
                 'chr1\tHAVANA\ttranscript\t10\t20\t.\t-\t.\ttranscript_id "ENST_A";gene_name "TEST1"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n' \
+                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n' \
                 'chr1\tHAVANA\tgene\t100\t110\t.\t-\t.\tgene_name "TEST2";\n' \
                 'chr1\tHAVANA\ttranscript\t100\t110\t.\t-\t.\ttranscript_id "ENST_B";gene_name "TEST2"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST2"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t105\t110\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST2"; transcript_type "protein_coding"\n'\
+                'chr1\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST2"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t105\t110\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST2"; transcript_type "protein_coding;"\n'\
                 'chr2\tHAVANA\tgene\t100\t110\t.\t-\t.\tgene_name "TEST3";\n' \
                 'chr2\tHAVANA\ttranscript\t100\t110\t.\t-\t.\ttranscript_id "ENST_C";gene_name "TEST3"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
                 'chr2\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_C" gene_name "TEST3"; transcript_type "protein_coding"\n' \
@@ -112,16 +112,16 @@ class TestGencode(unittest.TestCase):
         lines = ['##format: gtf\n',
                 'chr1\tHAVANA\tgene\t10\t20\t.\t-\t.\tgene_name "TEST1";\n',
                 'chr1\tHAVANA\ttranscript\t10\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding"; tag "appris_principal_1";\n',
-                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n',
-                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n',
+                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n',
+                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n',
                 'chr1\tHAVANA\tgene\t100\t110\t.\t-\t.\tgene_name "TEST2";\n',
                 'chr1\tHAVANA\ttranscript\t100\t110\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST2"; transcript_type "protein_coding"; tag "appris_principal_1";\n',
-                'chr1\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST2"; transcript_type "protein_coding"\n',
-                'chr1\tHAVANA\tCDS\t105\t110\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST2"; transcript_type "protein_coding"\n',
+                'chr1\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST2"; transcript_type "protein_coding;"\n',
+                'chr1\tHAVANA\tCDS\t105\t110\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST2"; transcript_type "protein_coding;"\n',
                 'chr2\tHAVANA\tgene\t100\t110\t.\t-\t.\tgene_name "TEST3";\n',
                 'chr2\tHAVANA\ttranscript\t100\t110\t.\t-\t.\ttranscript_id "ENST_C"; gene_name "TEST3"; transcript_type "protein_coding"; tag "appris_principal_1";\n',
-                'chr2\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_C" gene_name "TEST3"; transcript_type "protein_coding"\n',
-                'chr2\tHAVANA\tCDS\t105\t110\t.\t-\t.\ttranscript_id "ENST_C" gene_name "TEST3"; transcript_type "protein_coding"\n']
+                'chr2\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_C"; gene_name "TEST3"; transcript_type "protein_coding;"\n',
+                'chr2\tHAVANA\tCDS\t105\t110\t.\t-\t.\ttranscript_id "ENST_C"; gene_name "TEST3"; transcript_type "protein_coding;"\n']
         
         write_gtf(self.temp_gtf_path, lines)
         make_fasta(self.temp_fasta_path, ['chr1', 'chr2'])
@@ -150,12 +150,12 @@ class TestGencode(unittest.TestCase):
         lines = ['##format: gtf\n',
                 'chr1\tHAVANA\tgene\t20\t30\t.\t-\t.\tgene_name "TEST1";\n',
                 'chr1\tHAVANA\ttranscript\t20\t30\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding"; tag "appris_principal_1";\n',
-                'chr1\tHAVANA\texon\t20\t30\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n',
-                'chr1\tHAVANA\tCDS\t25\t30\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n',
+                'chr1\tHAVANA\texon\t20\t30\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n',
+                'chr1\tHAVANA\tCDS\t25\t30\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n',
                 'chr1\tHAVANA\tgene\t100\t110\t.\t-\t.\tgene_name "TEST1";\n',
                 'chr1\tHAVANA\ttranscript\t100\t110\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST1"; transcript_type "protein_coding";\n',
-                'chr1\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST1"; transcript_type "protein_coding"\n',
-                'chr1\tHAVANA\tCDS\t110\t100\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST1"; transcript_type "protein_coding"\n',
+                'chr1\tHAVANA\texon\t100\t110\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST1"; transcript_type "protein_coding;"\n',
+                'chr1\tHAVANA\tCDS\t110\t100\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST1"; transcript_type "protein_coding;"\n',
         ]
         
         write_gtf(self.temp_gtf_path, lines)
@@ -164,7 +164,7 @@ class TestGencode(unittest.TestCase):
         
         gene = gencode['TEST1']
         canonical = gene.canonical 
-        self.assertEqual(canonical.get_name(), 'ENST_A')
+        self.assertEqual(canonical.name, 'ENST_A')
         del gencode
         
         # give the second transcript the appris_principal tag as well, which
@@ -176,7 +176,7 @@ class TestGencode(unittest.TestCase):
         
         gene = gencode['TEST1']
         canonical = gene.canonical
-        self.assertEqual(canonical.get_name(), 'ENST_B')
+        self.assertEqual(canonical.name, 'ENST_B')
         del gencode
     
     def test_parse_gtf_gene_line(self):
@@ -192,6 +192,7 @@ class TestGencode(unittest.TestCase):
             'end': 70008,
             'strand': b'+',
             'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4'],
             'tx_id': b'',
             'transcript_type': b'',
             'is_canonical': 0,
@@ -215,6 +216,69 @@ class TestGencode(unittest.TestCase):
             'end': 70008,
             'strand': b'+',
             'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4'],
+            'tx_id': b'ENST00000335137.3',
+            'transcript_type': b'protein_coding',
+            'is_canonical': 5,
+            }
+        self.assertEqual(obj, expected)
+    
+    def test_parse_gtf_transcript_line_alternate_ids(self):
+        ''' test we can parse a GTF line which includes both alternate IDs
+        '''
+        line = 'chr1\tHAVANA\ttranscript\t69091\t70008\t.\t+\t.\tgene_id "ENSG00000186092.4"; '\
+            'transcript_id "ENST00000335137.3"; gene_type "protein_coding"; ' \
+            'gene_status "KNOWN"; gene_name "OR4F5"; transcript_type "protein_coding"; ' \
+            'transcript_status "KNOWN"; transcript_name "OR4F5-001"; level 2; ' \
+            'protein_id "ENSP00000334393.3"; tag "basic"; transcript_support_level "NA"; ' \
+            'hgnc_id "HGNC:14825"; tag "appris_principal_1"; tag "CCDS"; ccdsid "CCDS30547.1"; ' \
+            'havana_gene "OTTHUMG00000001094.2"; havana_transcript "OTTHUMT00000003223.2";\n'
+        obj = _parse_gtfline(line.encode('utf8'))
+        expected = {'chrom': b'chr1', 
+            'feature': b'transcript', 
+            'start': 69091,
+            'end': 70008,
+            'strand': b'+',
+            'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4', b'HGNC:14825'],
+            'tx_id': b'ENST00000335137.3',
+            'transcript_type': b'protein_coding',
+            'is_canonical': 5,
+            }
+        self.assertEqual(obj, expected)
+        
+        # try without alternate gene ID from ensembl gene ID
+        line = 'chr1\tHAVANA\ttranscript\t69091\t70008\t.\t+\t.\t '\
+            'transcript_id "ENST00000335137.3"; gene_type "protein_coding"; ' \
+            'gene_status "KNOWN"; gene_name "OR4F5"; transcript_type "protein_coding";' \
+            'hgnc_id "HGNC:14825"; tag "appris_principal_1"; tag "CCDS"; ccdsid "CCDS30547.1"; '
+        obj = _parse_gtfline(line.encode('utf8'))
+        expected = {'chrom': b'chr1', 
+            'feature': b'transcript', 
+            'start': 69091,
+            'end': 70008,
+            'strand': b'+',
+            'symbol': b'OR4F5',
+            'alternate_ids': [b'HGNC:14825'],
+            'tx_id': b'ENST00000335137.3',
+            'transcript_type': b'protein_coding',
+            'is_canonical': 5,
+            }
+        self.assertEqual(obj, expected)
+        
+        # try without any alternate ID
+        line = 'chr1\tHAVANA\ttranscript\t69091\t70008\t.\t+\t.\t '\
+            'transcript_id "ENST00000335137.3"; gene_type "protein_coding"; ' \
+            'gene_status "KNOWN"; gene_name "OR4F5"; transcript_type "protein_coding";' \
+            'tag "appris_principal_1"; tag "CCDS"; ccdsid "CCDS30547.1"; '
+        obj = _parse_gtfline(line.encode('utf8'))
+        expected = {'chrom': b'chr1', 
+            'feature': b'transcript', 
+            'start': 69091,
+            'end': 70008,
+            'strand': b'+',
+            'symbol': b'OR4F5',
+            'alternate_ids': [],
             'tx_id': b'ENST00000335137.3',
             'transcript_type': b'protein_coding',
             'is_canonical': 5,
@@ -239,6 +303,7 @@ class TestGencode(unittest.TestCase):
             'end': 70008,
             'strand': b'+',
             'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4'],
             'tx_id': b'ENST00000335137.3',
             'transcript_type': b'protein_coding',
             'is_canonical': 0,  ## exons don't get checked for principal tag
@@ -263,6 +328,7 @@ class TestGencode(unittest.TestCase):
             'end': 70005,
             'strand': b'+',
             'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4'],
             'tx_id': b'ENST00000335137.3',
             'transcript_type': b'protein_coding',
             'is_canonical': 0,  ## CDS don't get checked for principal tag
@@ -286,6 +352,7 @@ class TestGencode(unittest.TestCase):
             'end': 69093,
             'strand': b'+',
             'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4'],
             'tx_id': b'ENST00000335137.3',
             'transcript_type': b'protein_coding',
             'is_canonical': 0,
@@ -309,6 +376,7 @@ class TestGencode(unittest.TestCase):
             'end': 70008,
             'strand': b'+',
             'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4'],
             'tx_id': b'ENST00000335137.3',
             'transcript_type': b'protein_coding',
             'is_canonical': 0,
@@ -332,6 +400,7 @@ class TestGencode(unittest.TestCase):
             'end': 70008,
             'strand': b'+',
             'symbol': b'OR4F5',
+            'alternate_ids': [b'ENSG00000186092.4'],
             'tx_id': b'ENST00000335137.3',
             'transcript_type': b'protein_coding',
             'is_canonical': 0,
@@ -349,6 +418,7 @@ class TestGencode(unittest.TestCase):
             'end': 70008,
             'strand': b'-',
             'symbol': b'TEST',
+            'alternate_ids': [],
             'tx_id': b'',
             'transcript_type': b'',
             'is_canonical': 0,
@@ -361,12 +431,12 @@ class TestGencode(unittest.TestCase):
         lines = '##format: gtf\n' \
                 'chr1\tHAVANA\tgene\t10\t20\t.\t-\t.\tgene_name "TEST1";\n' \
                 'chr1\tHAVANA\ttranscript\t10\t20\t.\t-\t.\ttranscript_id "ENST_A";gene_name "TEST1"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST1"; transcript_type "protein_coding"\n' \
+                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST1"; transcript_type "protein_coding;"\n' \
                 'chr1\tHAVANA\tgene\t10\t30\t.\t-\t.\tgene_name "TEST2";\n' \
                 'chr1\tHAVANA\ttranscript\t10\t30\t.\t-\t.\ttranscript_id "ENST_B";gene_name "TEST2"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\texon\t10\t30\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST2"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t15\t30\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST2"; transcript_type "protein_coding"\n'
+                'chr1\tHAVANA\texon\t10\t30\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST2"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t15\t30\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST2"; transcript_type "protein_coding;"\n'
         
         write_gtf(self.temp_gtf_path, lines)
         data = _open_gencode(self.temp_gtf_path)
@@ -382,8 +452,8 @@ class TestGencode(unittest.TestCase):
         lines = '##format: gtf\n' \
                 'chr1\tHAVANA\tgene\t10\t20\t.\t-\t.\tgene_name "TEST";\n' \
                 'chr1\tHAVANA\ttranscript\t10\t20\t.\t-\t.\ttranscript_id "ENST_A";gene_name "TEST"; transcript_type "processed_transcript"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "processed_transcript"\n' \
-                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "processed_transcript"\n' \
+                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "processed_transcript;"\n' \
+                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "processed_transcript;"\n' \
                         
         write_gtf(self.temp_gtf_path, lines)
         data = _open_gencode(self.temp_gtf_path)
@@ -402,12 +472,12 @@ class TestGencode(unittest.TestCase):
         lines = '##format: gtf\n' \
                 'chr1\tHAVANA\tgene\t10\t20\t.\t-\t.\tgene_name "TEST";\n' \
                 'chr1\tHAVANA\ttranscript\t10\t20\t.\t-\t.\ttranscript_id "ENST_A";gene_name "TEST"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n' \
+                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
                 'chr1\tHAVANA\tgene\t10\t30\t.\t-\t.\tgene_name "TEST";\n' \
                 'chr1\tHAVANA\ttranscript\t10\t30\t.\t-\t.\ttranscript_id "ENST_B";gene_name "TEST"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\texon\t10\t30\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t15\t30\t.\t-\t.\ttranscript_id "ENST_B" gene_name "TEST"; transcript_type "protein_coding"\n'
+                'chr1\tHAVANA\texon\t10\t30\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t15\t30\t.\t-\t.\ttranscript_id "ENST_B"; gene_name "TEST"; transcript_type "protein_coding;"\n'
         
         write_gtf(self.temp_gtf_path, lines)
         data = _open_gencode(self.temp_gtf_path)
@@ -416,10 +486,10 @@ class TestGencode(unittest.TestCase):
         symbol1, tx1, is_principal = data[0]
         symbol2, tx2, is_principal = data[1]
         self.assertEqual(symbol1, symbol2)
-        self.assertEqual(tx1.get_name(), 'ENST_A')
-        self.assertEqual(tx1.get_cds(), [{'start': 15, 'end': 20}])
-        self.assertEqual(tx2.get_name(), 'ENST_B')
-        self.assertEqual(tx2.get_cds(), [{'start': 15, 'end': 30}])
+        self.assertEqual(tx1.name, 'ENST_A')
+        self.assertEqual(tx1.cds, [{'start': 15, 'end': 20}])
+        self.assertEqual(tx2.name, 'ENST_B')
+        self.assertEqual(tx2.cds, [{'start': 15, 'end': 30}])
         
     def test__open_gencode_multi_exon(self):
         '''test we can parse a GTF into transcripts
@@ -427,13 +497,13 @@ class TestGencode(unittest.TestCase):
         lines = '##format: gtf\n' \
                 'chr1\tHAVANA\tgene\t10\t100\t.\t-\t.\tgene_name "TEST";\n' \
                 'chr1\tHAVANA\ttranscript\t10\t100\t.\t-\t.\ttranscript_id "ENST_A";gene_name "TEST"; transcript_type "protein_coding"; tag "appris_principal_1";\n' \
-                'chr1\tHAVANA\tUTR\t10\t15\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding";\n' \
-                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\texon\t30\t40\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tCDS\t30\t40\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\texon\t90\t100\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n' \
-                'chr1\tHAVANA\tUTR\t90\t100\t.\t-\t.\ttranscript_id "ENST_A" gene_name "TEST"; transcript_type "protein_coding"\n'
+                'chr1\tHAVANA\tUTR\t10\t15\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding";\n' \
+                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\texon\t30\t40\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tCDS\t30\t40\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\texon\t90\t100\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n' \
+                'chr1\tHAVANA\tUTR\t90\t100\t.\t-\t.\ttranscript_id "ENST_A"; gene_name "TEST"; transcript_type "protein_coding;"\n'
         
         write_gtf(self.temp_gtf_path, lines)
         data = _open_gencode(self.temp_gtf_path)
@@ -441,9 +511,34 @@ class TestGencode(unittest.TestCase):
         self.assertEqual(len(data), 1)
         symbol, tx, is_principal = data[0]
         self.assertEqual(symbol, 'TEST')
-        self.assertEqual(tx.get_name(), 'ENST_A')
-        self.assertEqual(tx.get_strand(), '-')
-        self.assertEqual(tx.get_exons(), [{'start': 10, 'end': 20}, {'start': 30, 'end': 40}, {'start': 90, 'end': 100}])
-        self.assertEqual(tx.get_cds(), [{'start': 15, 'end': 20}, {'start': 30, 'end': 40}])
+        self.assertEqual(tx.name, 'ENST_A')
+        self.assertEqual(tx.strand, '-')
+        self.assertEqual(tx.exons, [{'start': 10, 'end': 20}, {'start': 30, 'end': 40}, {'start': 90, 'end': 100}])
+        self.assertEqual(tx.cds, [{'start': 15, 'end': 20}, {'start': 30, 'end': 40}])
+    
+    def test__open_gencode_unquoted(self):
+        '''test we can parse a GTF without quoted attributes
+        '''
+        lines = '##format: gtf\n' \
+                'chr1\tHAVANA\tgene\t10\t100\t.\t-\t.\tgene_name "TEST";\n' \
+                'chr1\tHAVANA\ttranscript\t10\t100\t.\t-\t.\ttranscript_id ENST_A;gene_name TEST; transcript_type protein_coding; tag appris_principal_1;\n' \
+                'chr1\tHAVANA\tUTR\t10\t15\t.\t-\t.\ttranscript_id ENST_A; gene_name TEST; transcript_type protein_coding;\n' \
+                'chr1\tHAVANA\texon\t10\t20\t.\t-\t.\ttranscript_id ENST_A; gene_name TEST; transcript_type protein_coding;\n' \
+                'chr1\tHAVANA\tCDS\t15\t20\t.\t-\t.\ttranscript_id ENST_A; gene_name TEST; transcript_type protein_coding;\n' \
+                'chr1\tHAVANA\texon\t30\t40\t.\t-\t.\ttranscript_id ENST_A; gene_name TEST; transcript_type protein_coding;\n' \
+                'chr1\tHAVANA\tCDS\t30\t40\t.\t-\t.\ttranscript_id ENST_A; gene_name TEST; transcript_type protein_coding;\n' \
+                'chr1\tHAVANA\texon\t90\t100\t.\t-\t.\ttranscript_id ENST_A; gene_name TEST; transcript_type protein_coding;\n' \
+                'chr1\tHAVANA\tUTR\t90\t100\t.\t-\t.\ttranscript_id ENST_A; gene_name TEST; transcript_type protein_coding;\n'
+        
+        write_gtf(self.temp_gtf_path, lines)
+        data = _open_gencode(self.temp_gtf_path)
+        
+        self.assertEqual(len(data), 1)
+        symbol, tx, is_principal = data[0]
+        self.assertEqual(symbol, 'TEST')
+        self.assertEqual(tx.name, 'ENST_A')
+        self.assertEqual(tx.strand, '-')
+        self.assertEqual(tx.exons, [{'start': 10, 'end': 20}, {'start': 30, 'end': 40}, {'start': 90, 'end': 100}])
+        self.assertEqual(tx.cds, [{'start': 15, 'end': 20}, {'start': 30, 'end': 40}])
     
 
